/** \file
*/
//---------------------------------------------------------------------------

#ifndef SettingsH
#define SettingsH
//---------------------------------------------------------------------------
#include <System.hpp>
#include "UaConf.h"
#include "ButtonConf.h"
#include "HotKeyConf.h"
#include "PhoneConf.h"
#include <list>

class Settings
{
public:
	int Read(AnsiString asFileName);
	int Write(AnsiString asFileName);
	void SetDefault(void);
	struct _gui
	{
		enum { SCALING_MIN = 50 };
		enum { SCALING_MAX = 200 };
		int scalingPct;					///< scaling (percentage)
	} gui;
	struct _frmMain
	{
		int iPosX, iPosY;				///< main window coordinates
		int iHeight, iWidth;			///< main window size
		bool bWindowMaximized;			///< is main window maximize?
		bool bAlwaysOnTop;
		bool bStartMinimizedToTray;
		bool bSpeedDialVisible;
		int iSpeedDialSize;				///< number of console columns
		int iSpeedDialWidth;			///< width of single console column
		bool bSpeedDialOnly;
		bool bXBtnMinimize;				///< minimize to tray when 'X' is pressed
		bool bRestoreOnIncomingCall;	///< restore minimized window on incoming call
		bool bSingleInstance;			///< check if another instance is running if started without parameters and bring it to front
	} frmMain;
	struct _frmTrayNotifier
	{
		int iPosX, iPosY;				///< coordinates
		int iHeight, iWidth;
		bool showOnIncoming;
		bool skipIfMainWindowVisible;
		bool showOnOutgoing;
	} frmTrayNotifier;
	struct _frmContactPopup
	{
		bool showOnIncoming;
		bool showOnOutgoing;
		int iPosX, iPosY;				///< coordinates
		int iHeight, iWidth;		
	} frmContactPopup;
	struct _Logging
	{
		bool bLogToFile;
		unsigned int iMaxUiLogLines;
	} Logging;
	struct _Integration
	{
		bool bAddFilterWMCopyData;
		AnsiString asProtocol;
	} Integration;
	struct _Ring
	{
		AnsiString defaultRing;
		AnsiString bellcore[8];
	} Ring;
	struct _HttpQuery
	{
    	AnsiString url;
	} HttpQuery;

	std::list<PhoneConf> phoneConf;

	UaConf uaConf;

	enum { EXT_CONSOLE_COLUMNS = 5 };
	enum { CONSOLE_BTNS_PER_COLUMN = 15 };	
	std::vector<ButtonConf> btnConf;

	std::list<HotKeyConf> hotKeyConf;

	void UpdateContacts(void);
};

extern Settings appSettings;

#endif
